==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver Gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Cores</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_pt.ts--
Ver gráficos</translatorcomment>
        <translation type="obsolete">Ver gráficos</translation>
    </message>
    <message>
        <source>Colors</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Cores
Cores &amp;básicas</translatorcomment>
        <translation type="obsolete">Cores</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pano de Fundo:
Pano de Fundo do Desenho:</translatorcomment>
        <translation>Pano de Fundo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Miras:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Miras inativas:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origem</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Zero relativo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Grade</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Metagrade:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Seleção</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">Primeira cor para a seleção</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Cor principal para seleção:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Use cor secundária para seleção</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Cor secundária para seleção:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Pontos de referência arrastáveis:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Pontos de referência secundária:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Borda da caixa de seleção:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Preenchimento da caixa de seleção:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Preenchimento da caixa de seleção cruzada:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Ferramentas de Salto</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Rótulo do salto:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Ferramentas de Informação</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Dimensões e rótulos:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Ferramentas de Desenho</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Formas auxiliares:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Ferramentas de Zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Borda da caixa de zoom:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mira inativos:</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>Origin:</source>
        <translatorcomment>--exact match--
--file: qgis_pt.ts--
Origem:</translatorcomment>
        <translation>Origem:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zero relativo:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translatorcomment>--exact match--
--file: LineAngle_pt.ts--
Ponto de &amp;referência:
Ponto de referência:</translatorcomment>
        <translation type="obsolete">Ponto de referência:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: pt.po--
&amp;Meta-grade:
Meta-grade:</translatorcomment>
        <translation>Grade:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translatorcomment>--google--
&amp;Meta-grade:
Meta-grade:</translatorcomment>
        <translation type="obsolete">Grade meta:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Caixa de zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Selecção:</translatorcomment>
        <translation type="obsolete">Selecção:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Borda da caixa de seleção:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Caixa de seleção:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Caixa de seleção de captura:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Formas auxiliares:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fundo de etiqueta info:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fonte de etiqueta info:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ferramentas de medição:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver Gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Cores</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_pt.ts--
Ver gráficos</translatorcomment>
        <translation type="obsolete">Ver gráficos</translation>
    </message>
    <message>
        <source>Colors</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Cores
Cores &amp;básicas</translatorcomment>
        <translation type="obsolete">Cores</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pano de Fundo:
Pano de Fundo do Desenho:</translatorcomment>
        <translation>Pano de Fundo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Miras:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Miras inativas:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origem</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Zero relativo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Grade</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Metagrade:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Seleção</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">Primeira cor para a seleção</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Cor principal para seleção:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Use cor secundária para seleção</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Cor secundária para seleção:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Pontos de referência arrastáveis:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Pontos de referência secundária:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Borda da caixa de seleção:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Preenchimento da caixa de seleção:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Preenchimento da caixa de seleção cruzada:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Pontos iniciais:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Pontos finais:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Ferramentas de Salto</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Rótulo do salto:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Ferramentas de Informação</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Dimensões e rótulos:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Ferramentas de Desenho</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Formas auxiliares:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Ferramentas de Zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Borda da caixa de zoom:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mira inativos:</translation>
    </message>
    <message>
        <location line="-616"/>
        <source>Origin:</source>
        <translatorcomment>--exact match--
--file: qgis_pt.ts--
Origem:</translatorcomment>
        <translation>Origem:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zero relativo:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translatorcomment>--exact match--
--file: LineAngle_pt.ts--
Ponto de &amp;referência:
Ponto de referência:</translatorcomment>
        <translation type="obsolete">Ponto de referência:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: pt.po--
&amp;Meta-grade:
Meta-grade:</translatorcomment>
        <translation>Grade:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translatorcomment>--google--
&amp;Meta-grade:
Meta-grade:</translatorcomment>
        <translation type="obsolete">Grade meta:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Caixa de zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Selecção:</translatorcomment>
        <translation type="obsolete">Selecção:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Borda da caixa de seleção:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Caixa de seleção:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Caixa de seleção de captura:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Formas auxiliares:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fundo de etiqueta info:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fonte de etiqueta info:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Ferramentas de medição:</translation>
    </message>
</context>
</TS>
